---
title: <span class="badge object-type-scalar"></span> PartsPerBillion
---
# <span class="badge object-type-scalar"></span> PartsPerBillion

Concentration: parts-per-billion (ppb)

## Definition

```python
# Concentration: parts-per-billion (ppb)
PartsPerBillion: typing.Literal["conppb"] = "conppb"
```
